@@ -78,6 +78,7 @@ typedef struct
 	int uncapped;
 	int vsync;
 	int weaponsquat;
+	int widescreen;
 
 	// [crispy] in-game switches and variables
 	int screenshotmsg;
@@ -114,14 +115,6 @@ enum
 	REINIT_ASPECTRATIO = 8,
 };
 
-enum
-{
-    ASPECTRATIO_OFF,
-    ASPECTRATIO_4_3,
-    ASPECTRATIO_16_10,
-    NUM_ASPECTRATIOS,
-};
-
 enum
 {
     BOBFACTOR_FULL,
