@@ -88,6 +88,8 @@
 //
 void D_DoomLoop (void);
 
+static char *gamedescription;
+
 // Location where savegames are stored
 
 char *          savegamedir;
@@ -318,7 +320,7 @@ boolean D_Display (void)
 	    y = 4;
 	else
 	    y = (viewwindowy >> crispy->hires)+4;
-	V_DrawPatchDirect((viewwindowx >> crispy->hires) + ((scaledviewwidth >> crispy->hires) - 68) / 2, y,
+	V_DrawPatchDirect((viewwindowx >> crispy->hires) + ((scaledviewwidth >> crispy->hires) - 68) / 2 - WIDESCREENDELTA, y,
                           W_CacheLumpName (DEH_String("M_PAUSE"), PU_CACHE));
     }
 
@@ -447,6 +449,7 @@ void D_BindVariables(void)
     M_BindIntVariable("crispy_uncapped",        &crispy->uncapped);
     M_BindIntVariable("crispy_vsync",           &crispy->vsync);
     M_BindIntVariable("crispy_weaponsquat",     &crispy->weaponsquat);
+    M_BindIntVariable("crispy_widescreen",      &crispy->widescreen);
 }
 
 //
@@ -525,7 +528,7 @@ void D_RunFrame()
 	// [crispy] post-rendering function pointer to apply config changes
 	// that affect rendering and that are better applied after the current
 	// frame has finished rendering
-	if (crispy->post_rendering_hook)
+	if (crispy->post_rendering_hook && !wipe)
 	{
 		crispy->post_rendering_hook();
 		crispy->post_rendering_hook = NULL;
@@ -774,47 +777,52 @@ static const char *banners[] =
 // Otherwise, use the name given
 // 
 
-static char *GetGameName(char *gamename)
+static char *GetGameName(const char *gamename)
 {
     size_t i;
-    const char *deh_sub;
-    
+
     for (i=0; i<arrlen(banners); ++i)
     {
+        const char *deh_sub;
         // Has the banner been replaced?
 
         deh_sub = DEH_String(banners[i]);
-        
+
         if (deh_sub != banners[i])
         {
             size_t gamename_size;
             int version;
+            char *deh_gamename;
 
             // Has been replaced.
             // We need to expand via printf to include the Doom version number
             // We also need to cut off spaces to get the basic name
 
             gamename_size = strlen(deh_sub) + 10;
-            gamename = Z_Malloc(gamename_size, PU_STATIC, 0);
+            deh_gamename = malloc(gamename_size);
+            if (deh_gamename == NULL)
+            {
+                I_Error("GetGameName: Failed to allocate new string");
+            }
             version = G_VanillaVersionCode();
-            M_snprintf(gamename, gamename_size, deh_sub,
-                       version / 100, version % 100);
+            DEH_snprintf(deh_gamename, gamename_size, banners[i],
+                         version / 100, version % 100);
 
-            while (gamename[0] != '\0' && isspace(gamename[0]))
+            while (deh_gamename[0] != '\0' && isspace(deh_gamename[0]))
             {
-                memmove(gamename, gamename + 1, gamename_size - 1);
+                memmove(deh_gamename, deh_gamename + 1, gamename_size - 1);
             }
 
-            while (gamename[0] != '\0' && isspace(gamename[strlen(gamename)-1]))
+            while (deh_gamename[0] != '\0' && isspace(deh_gamename[strlen(deh_gamename)-1]))
             {
-                gamename[strlen(gamename) - 1] = '\0';
+                deh_gamename[strlen(deh_gamename) - 1] = '\0';
             }
 
-            return gamename;
+            return deh_gamename;
         }
     }
 
-    return gamename;
+    return M_StringDuplicate(gamename);
 }
 
 static void SetMissionForPackName(const char *pack_name)
@@ -937,10 +945,8 @@ void D_IdentifyVersion(void)
 
 // Set the gamedescription string
 
-void D_SetGameDescription(void)
+static void D_SetGameDescription(void)
 {
-    gamedescription = "Unknown";
-
     if (logical_gamemission == doom)
     {
         // Doom 1.  But which version?
@@ -997,6 +1003,11 @@ void D_SetGameDescription(void)
             gamedescription = GetGameName("Master Levels for DOOM 2");
         }
     }
+
+    if (gamedescription == NULL)
+    {
+        gamedescription = M_StringDuplicate("Unknown");
+    }
 }
 
 //      print title for every printed line
@@ -1947,6 +1958,42 @@ void D_DoomMain (void)
 	}
     }
 
+    //!
+    // @arg <file>
+    // @category mod
+    //
+    // [crispy] experimental feature: dump lump data into a new LMP file <file>
+    //
+
+    p = M_CheckParm("-lumpdump");
+
+    if (p)
+    {
+	p = M_CheckParmWithArgs("-lumpdump", 1);
+
+	if (p)
+	{
+	    int dumped;
+
+	    M_StringCopy(file, myargv[p+1], sizeof(file));
+
+	    dumped = W_LumpDump(file);
+
+	    if (dumped < 0)
+	    {
+		I_Error("W_LumpDump: Failed to write lump '%s'.", file);
+	    }
+	    else
+	    {
+		I_Error("W_LumpDump: Dumped lump into file '%s.lmp'.", file);
+	    }
+	}
+	else
+	{
+	    I_Error("W_LumpDump: The '-lumpdump' parameter requires an argument.");
+	}
+    }
+
     // Debug:
 //    W_PrintDirectory();
 
