@@ -19,6 +19,7 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <stdlib.h>
 
 // Functions.
 #include "deh_main.h"
@@ -895,7 +896,7 @@ F_DrawPatchCol
     int		count;
 	
     column = (column_t *)((byte *)patch + LONG(patch->columnofs[col >> FRACBITS]));
-    desttop = I_VideoBuffer + x;
+    desttop = I_VideoBuffer + x + (WIDESCREENDELTA << crispy->hires);
 
     // step through the posts in a column
     while (column->topdelta != 0xff )
@@ -929,10 +930,16 @@ void F_BunnyScroll (void)
     int		stage;
     static int	laststage;
 		
-    dxi = (ORIGWIDTH << FRACBITS) / SCREENWIDTH;
+    dxi = (ORIGWIDTH << FRACBITS) / NONWIDEWIDTH;
     dy = (SCREENHEIGHT << FRACBITS) / ORIGHEIGHT;
     dyi = (ORIGHEIGHT << FRACBITS) / SCREENHEIGHT;
 
+    // [crispy] fill pillarboxes in widescreen mode
+    if (SCREENWIDTH != NONWIDEWIDTH)
+    {
+	V_DrawFilledBox(0, 0, SCREENWIDTH, SCREENHEIGHT, 0);
+    }
+
     p1 = W_CacheLumpName (DEH_String("PFUB2"), PU_LEVEL);
     p2 = W_CacheLumpName (DEH_String("PFUB1"), PU_LEVEL);
 
