@@ -819,6 +819,9 @@ void G_DoLoadLevel (void)
 
         if (gamemap < 12)
         {
+            if (gamemission == pack_nerve && gamemap >= 4 && gamemap <= 8)
+                skytexturename = "SKY3";
+            else
             skytexturename = "SKY1";
         }
         else if (gamemap < 21)
@@ -1357,6 +1360,8 @@ void G_PlayerReborn (int player)
     p->usedown = p->attackdown = true;	// don't do anything immediately 
     p->playerstate = PST_LIVE;       
     p->health = deh_initial_health;     // Use dehacked value
+    // [crispy] negative player health
+    p->neghealth = p->health;
     p->readyweapon = p->pendingweapon = wp_pistol; 
     p->weaponowned[wp_fist] = true; 
     p->weaponowned[wp_pistol] = true; 
