@@ -17,6 +17,7 @@
 
 
 #include <ctype.h>
+#include <stdlib.h>
 
 #include "doomdef.h"
 #include "doomkeys.h"
@@ -60,7 +61,7 @@
 #define HU_TITLEM	(mapnames_commercial[gamemap-1 + 105 + 3])
 #define HU_TITLE_CHEX   (mapnames_chex[(gameepisode-1)*9+gamemap-1])
 #define HU_TITLEHEIGHT	1
-#define HU_TITLEX	0
+#define HU_TITLEX	(0 - WIDESCREENDELTA)
 #define HU_TITLEY	(167 - SHORT(hu_font[0]->height))
 
 #define HU_INPUTTOGGLE	't'
@@ -69,7 +70,7 @@
 #define HU_INPUTWIDTH	64
 #define HU_INPUTHEIGHT	1
 
-#define HU_COORDX	(ORIGWIDTH - 7 * hu_font['A'-HU_FONTSTART]->width)
+#define HU_COORDX	((ORIGWIDTH - 7 * hu_font['A'-HU_FONTSTART]->width) + WIDESCREENDELTA)
 
 
 char *chat_macros[10] =
@@ -592,6 +593,8 @@ static void HU_SetSpecialLevelName (const char *wad, const char **name)
     }
 }
 
+static int hu_widescreendelta;
+
 void HU_Start(void)
 {
 
@@ -610,6 +613,10 @@ void HU_Start(void)
     secret_on = false;
     chat_on = false;
 
+    // [crispy] re-calculate WIDESCREENDELTA
+    I_GetScreenDimensions();
+    hu_widescreendelta = WIDESCREENDELTA;
+
     // create the message widget
     HUlib_initSText(&w_message,
 		    HU_MSGX, HU_MSGY, HU_MSGHEIGHT,
@@ -827,7 +834,7 @@ void HU_Drawer(void)
     }
 
     // [crispy] translucent messages for translucent HUD
-    if (screenblocks > CRISPY_HUD + 1 && (!automapactive || crispy->automapoverlay))
+    if (screenblocks >= CRISPY_HUD && (screenblocks % 3 == 2) && (!automapactive || crispy->automapoverlay))
 	dp_translucent = true;
 
     if (secret_on && !menuactive)
@@ -883,9 +890,7 @@ void HU_Drawer(void)
 	HU_DrawCrosshair();
 
     dp_translation = NULL;
-
-    if (dp_translucent)
-	dp_translucent = false;
+    dp_translucent = false;
 
     // [crispy] demo timer widget
     if (demoplayback && (crispy->demotimer & DEMOTIMER_PLAYBACK))
@@ -930,6 +935,12 @@ void HU_Ticker(void)
     char c;
     char str[32], *s;
 
+    // [crispy] re-calculate widget coordinates on demand
+    if (hu_widescreendelta != WIDESCREENDELTA)
+    {
+        HU_Start();
+    }
+
     // tick down message counter if message is up
     if (message_counter && !--message_counter)
     {
