@@ -25,13 +25,6 @@
 
 #include "m_crispy.h"
 
-multiitem_t multiitem_aspectratio[NUM_ASPECTRATIOS] =
-{
-    {ASPECTRATIO_OFF, "none"},
-    {ASPECTRATIO_4_3, "4:3"},
-    {ASPECTRATIO_16_10, "16:10"},
-};
-
 multiitem_t multiitem_bobfactor[NUM_BOBFACTORS] =
 {
     {BOBFACTOR_FULL, "full"},
@@ -142,29 +135,13 @@ multiitem_t multiitem_widgets[NUM_WIDGETS] =
     {WIDGETS_ALWAYS, "always"},
 };
 
-extern void AM_ReInit (void);
+extern void AM_LevelInit (boolean reinit);
 extern void EnableLoadingDisk (void);
 extern void P_SegLengths (boolean contrast_only);
 extern void R_ExecuteSetViewSize (void);
 extern void R_InitLightTables (void);
 extern void I_ReInitGraphics (int reinit);
 
-static void M_CrispyToggleAspectRatioHook (void)
-{
-    aspect_ratio_correct = (aspect_ratio_correct + 1) % NUM_ASPECTRATIOS;
-
-    // [crispy] re-set logical rendering resolution
-
-    I_ReInitGraphics(REINIT_ASPECTRATIO);
-}
-
-void M_CrispyToggleAspectRatio(int choice)
-{
-    choice = 0;
-
-    crispy->post_rendering_hook = M_CrispyToggleAspectRatioHook;
-}
-
 void M_CrispyToggleAutomapstats(int choice)
 {
     choice = 0;
@@ -195,7 +172,6 @@ void M_CrispyToggleColoredblood(int choice)
 
     if (gameversion == exe_chex)
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -252,7 +228,6 @@ void M_CrispyToggleCrosshairtype(int choice)
 {
     if (!crispy->crosshair)
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -281,7 +256,6 @@ void M_CrispyToggleDemoTimerDir(int choice)
 {
     if (!(crispy->demotimer & DEMOTIMER_PLAYBACK))
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -305,7 +279,6 @@ void M_CrispyToggleFlipcorpses(int choice)
 {
     if (gameversion == exe_chex)
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -317,7 +290,6 @@ void M_CrispyToggleFreeaim(int choice)
 {
     if (!crispy->singleplayer)
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -372,7 +344,7 @@ static void M_CrispyToggleHiresHook (void)
     // [crispy] re-calculate disk icon coordinates
     EnableLoadingDisk();
     // [crispy] re-calculate automap coordinates
-    AM_ReInit();
+    AM_LevelInit(true);
 }
 
 void M_CrispyToggleHires(int choice)
@@ -386,7 +358,6 @@ void M_CrispyToggleJumping(int choice)
 {
     if (!crispy->singleplayer)
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -421,7 +392,6 @@ void M_CrispyToggleOverunder(int choice)
 {
     if (!crispy->singleplayer)
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -450,7 +420,6 @@ void M_CrispyToggleRecoil(int choice)
 {
     if (!crispy->singleplayer)
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -539,7 +508,6 @@ void M_CrispyToggleVsync(int choice)
 
     if (force_software_renderer)
     {
-	S_StartSound(NULL,sfx_oof);
 	return;
     }
 
@@ -551,3 +519,29 @@ void M_CrispyToggleWeaponSquat(int choice)
     choice = 0;
     crispy->weaponsquat = !crispy->weaponsquat;
 }
+
+static void M_CrispyToggleWidescreenHook (void)
+{
+    crispy->widescreen = !crispy->widescreen;
+
+    // [crispy] no need to re-init when switching from wide to compact
+    {
+	// [crispy] re-initialize framebuffers, textures and renderer
+	I_ReInitGraphics(REINIT_FRAMEBUFFERS | REINIT_TEXTURES | REINIT_ASPECTRATIO);
+	// [crispy] re-calculate framebuffer coordinates
+	R_ExecuteSetViewSize();
+	// [crispy] re-draw bezel
+	R_FillBackScreen();
+	// [crispy] re-calculate disk icon coordinates
+	EnableLoadingDisk();
+	// [crispy] re-calculate automap coordinates
+	AM_LevelInit(true);
+    }
+}
+
+void M_CrispyToggleWidescreen(int choice)
+{
+    choice = 0;
+
+    crispy->post_rendering_hook = M_CrispyToggleWidescreenHook;
+}
