@@ -20,6 +20,7 @@
 
 
 #include <math.h>
+#include <stdlib.h>
 
 #include "z_zone.h"
 
@@ -553,7 +554,7 @@ void P_LoadLineDefs (int lump)
 	ld->flags = (unsigned short)SHORT(mld->flags); // [crispy] extended nodes
 	ld->special = SHORT(mld->special);
 	// [crispy] warn about unknown linedef types
-	if ((unsigned short) ld->special > 141)
+	if ((unsigned short) ld->special > 141 && ld->special != 271 && ld->special != 272)
 	{
 	    fprintf(stderr, "P_LoadLineDefs: Unknown special %d at line %d.\n", ld->special, i);
 	    warn++;
