@@ -21,6 +21,7 @@
 
 
 #include <stdio.h>
+#include <ctype.h>
 
 #include "i_swap.h" // [crispy] SHORT()
 #include "i_system.h"
@@ -138,75 +139,78 @@ extern boolean inhelpscreens; // [crispy] prevent palette changes
 //       into a buffer,
 //       or into the frame buffer?
 
+// [crispy] in non-widescreen mode WIDESCREENDELTA is 0 anyway
+#define ST_WIDESCREENDELTA ((screenblocks >= CRISPY_HUD + 3 && (!automapactive || crispy->automapoverlay)) ? WIDESCREENDELTA : 0)
+
 // AMMO number pos.
 #define ST_AMMOWIDTH		3	
-#define ST_AMMOX			44
+#define ST_AMMOX			(44 - ST_WIDESCREENDELTA)
 #define ST_AMMOY			171
 
 // HEALTH number pos.
 #define ST_HEALTHWIDTH		3	
-#define ST_HEALTHX			90
+#define ST_HEALTHX			(90 - ST_WIDESCREENDELTA)
 #define ST_HEALTHY			171
 
 // Weapon pos.
-#define ST_ARMSX			111
+#define ST_ARMSX			(111 - ST_WIDESCREENDELTA)
 #define ST_ARMSY			172
-#define ST_ARMSBGX			104
+#define ST_ARMSBGX			(104 - ST_WIDESCREENDELTA)
 #define ST_ARMSBGY			168
 #define ST_ARMSXSPACE		12
 #define ST_ARMSYSPACE		10
 
 // Frags pos.
-#define ST_FRAGSX			138
+#define ST_FRAGSX			(138 - ST_WIDESCREENDELTA)
 #define ST_FRAGSY			171	
 #define ST_FRAGSWIDTH		2
 
 // ARMOR number pos.
 #define ST_ARMORWIDTH		3
-#define ST_ARMORX			221
+#define ST_ARMORX			(221 + ST_WIDESCREENDELTA)
 #define ST_ARMORY			171
 
 // Key icon positions.
 #define ST_KEY0WIDTH		8
 #define ST_KEY0HEIGHT		5
-#define ST_KEY0X			239
+#define ST_KEY0X			(239 + ST_WIDESCREENDELTA)
 #define ST_KEY0Y			171
 #define ST_KEY1WIDTH		ST_KEY0WIDTH
-#define ST_KEY1X			239
+#define ST_KEY1X			(239 + ST_WIDESCREENDELTA)
 #define ST_KEY1Y			181
 #define ST_KEY2WIDTH		ST_KEY0WIDTH
-#define ST_KEY2X			239
+#define ST_KEY2X			(239 + ST_WIDESCREENDELTA)
 #define ST_KEY2Y			191
 
 // Ammunition counter.
 #define ST_AMMO0WIDTH		3
 #define ST_AMMO0HEIGHT		6
-#define ST_AMMO0X			288
+#define ST_AMMO0X			(288 + ST_WIDESCREENDELTA)
 #define ST_AMMO0Y			173
 #define ST_AMMO1WIDTH		ST_AMMO0WIDTH
-#define ST_AMMO1X			288
+#define ST_AMMO1X			(288 + ST_WIDESCREENDELTA)
 #define ST_AMMO1Y			179
 #define ST_AMMO2WIDTH		ST_AMMO0WIDTH
-#define ST_AMMO2X			288
+#define ST_AMMO2X			(288 + ST_WIDESCREENDELTA)
 #define ST_AMMO2Y			191
 #define ST_AMMO3WIDTH		ST_AMMO0WIDTH
-#define ST_AMMO3X			288
+#define ST_AMMO3X			(288 + ST_WIDESCREENDELTA)
 #define ST_AMMO3Y			185
 
 // Indicate maximum ammunition.
 // Only needed because backpack exists.
 #define ST_MAXAMMO0WIDTH		3
 #define ST_MAXAMMO0HEIGHT		5
-#define ST_MAXAMMO0X		314
+#define ST_MAXAMMO0X		(314 + ST_WIDESCREENDELTA)
 #define ST_MAXAMMO0Y		173
 #define ST_MAXAMMO1WIDTH		ST_MAXAMMO0WIDTH
-#define ST_MAXAMMO1X		314
+#define ST_MAXAMMO1X		(314 + ST_WIDESCREENDELTA)
 #define ST_MAXAMMO1Y		179
 #define ST_MAXAMMO2WIDTH		ST_MAXAMMO0WIDTH
-#define ST_MAXAMMO2X		314
+#define ST_MAXAMMO2X		(314 + ST_WIDESCREENDELTA)
 #define ST_MAXAMMO2Y		191
 #define ST_MAXAMMO3WIDTH		ST_MAXAMMO0WIDTH
-#define ST_MAXAMMO3X		314
+#define ST_MAXAMMO3X		(314 + ST_WIDESCREENDELTA)
 #define ST_MAXAMMO3Y		185
 
 // pistol
@@ -476,6 +480,28 @@ void ST_refreshBackground(boolean force)
     {
         V_UseBuffer(st_backing_screen);
 
+	// [crispy] this is our own local copy of R_FillBackScreen() to
+	// fill the entire background of st_backing_screen with the bezel pattern,
+	// so it appears to the left and right of the status bar in widescreen mode
+	if ((SCREENWIDTH >> crispy->hires) != ST_WIDTH)
+	{
+		int x, y;
+		byte *src;
+		pixel_t *dest;
+		const char *name = (gamemode == commercial) ? DEH_String("GRNROCK") : DEH_String("FLOOR7_2");
+
+		src = W_CacheLumpName(name, PU_CACHE);
+		dest = st_backing_screen;
+
+		for (y = SCREENHEIGHT-(ST_HEIGHT<<crispy->hires); y < SCREENHEIGHT; y++)
+		{
+			for (x = 0; x < SCREENWIDTH; x++)
+			{
+				*dest++ = src[((y&63)<<6) + (x&63)];
+			}
+		}
+	}
+
 	V_DrawPatch(ST_X, 0, sbar);
 
 	// draw right side of bar if needed (Doom 1.0)
@@ -491,8 +517,10 @@ void ST_refreshBackground(boolean force)
 
         V_RestoreBuffer();
 
+	// [crispy] copy entire SCREENWIDTH, to preserve the pattern
+	// to the left and right of the status bar in widescren mode
 	if (!force)
-	V_CopyRect(ST_X, 0, st_backing_screen, ST_WIDTH, ST_HEIGHT, ST_X, ST_Y);
+	V_CopyRect(ST_X, 0, st_backing_screen, SCREENWIDTH >> crispy->hires, ST_HEIGHT, ST_X, ST_Y);
     }
 
 }
@@ -1340,8 +1368,7 @@ void ST_updateFaceWidget(void)
     if (priority < 10)
     {
 	// dead
-	// [crispy] negative player health
-	if (plyr->health <= 0)
+	if (!plyr->health)
 	{
 	    priority = 9;
 	    painoffset = 0;
@@ -1602,8 +1629,16 @@ void ST_updateWidgets(void)
 
 }
 
+static int st_widescreendelta;
+
 void ST_Ticker (void)
 {
+    // [crispy] re-calculate widget coordinates on demand
+    if (st_widescreendelta != ST_WIDESCREENDELTA)
+    {
+        void ST_createWidgets (void);
+        ST_createWidgets();
+    }
 
     st_clock++;
     st_randomnumber = M_Random();
@@ -1824,7 +1859,7 @@ static inline void ST_DrawGibbedPlayerSprites (void)
 		                 ((plyr->mo->flags & MF_TRANSLATION) >> (MF_TRANSSHIFT - 8));
 	}
 
-	V_DrawPatch(73, 186, patch);
+	V_DrawPatch(ST_HEALTHX - 17, 186, patch);
 	dp_translation = NULL;
 }
 
@@ -1865,7 +1900,7 @@ void ST_drawWidgets(boolean refresh)
 		patch = W_CacheLumpNum(lump, PU_CACHE);
 
 		// [crispy] (23,179) is the center of the Ammo widget
-		V_DrawPatch(23 - SHORT(patch->width)/2 + SHORT(patch->leftoffset),
+		V_DrawPatch(ST_AMMOX - 21 - SHORT(patch->width)/2 + SHORT(patch->leftoffset),
 		            179 - SHORT(patch->height)/2 + SHORT(patch->topoffset),
 		            patch);
 
@@ -1889,6 +1924,8 @@ void ST_drawWidgets(boolean refresh)
     if (!gibbed)
     {
     dp_translation = ST_WidgetColor(hudcolor_health);
+    // [crispy] negative player health
+    w_health.n.num = crispy->neghealth ? &plyr->neghealth : &plyr->health;
     STlib_updatePercent(&w_health, refresh);
     }
     dp_translation = ST_WidgetColor(hudcolor_armor);
@@ -1904,9 +1941,9 @@ void ST_drawWidgets(boolean refresh)
 	STlib_updateMultIcon(&w_arms[i], refresh);
 
     // [crispy] draw the actual face widget background
-    if (st_crispyhud && screenblocks == CRISPY_HUD)
+    if (st_crispyhud && (screenblocks % 3 == 0))
     {
-	V_CopyRect(ST_FX, 1, st_backing_screen, SHORT(faceback->width), ST_HEIGHT - 1, ST_FX, ST_Y + 1);
+	V_CopyRect(ST_FX + WIDESCREENDELTA, 1, st_backing_screen, SHORT(faceback->width), ST_HEIGHT - 1, ST_FX + WIDESCREENDELTA, ST_Y + 1);
     }
 
     STlib_updateMultIcon(&w_faces, refresh);
@@ -1949,7 +1986,7 @@ void ST_Drawer (boolean fullscreen, boolean refresh)
     // [crispy] distinguish classic status bar with background and player face from Crispy HUD
     st_crispyhud = screenblocks >= CRISPY_HUD && (!automapactive || crispy->automapoverlay);
     st_classicstatusbar = st_statusbaron && !st_crispyhud;
-    st_statusbarface = st_classicstatusbar || (st_crispyhud && screenblocks == CRISPY_HUD);
+    st_statusbarface = st_classicstatusbar || (st_crispyhud && (screenblocks % 3 == 0));
 
     if (crispy->cleanscreenshot == 2)
         return;
@@ -1958,7 +1995,7 @@ void ST_Drawer (boolean fullscreen, boolean refresh)
     ST_doPaletteStuff();
 
     // [crispy] translucent HUD
-    if (st_crispyhud && screenblocks > CRISPY_HUD + 1)
+    if (st_crispyhud && (screenblocks % 3 == 2))
 	dp_translucent = true;
 
     // If just after ST_Start(), refresh all
@@ -2155,6 +2192,10 @@ void ST_createWidgets(void)
 
     int i;
 
+    // [crispy] re-calculate WIDESCREENDELTA
+    I_GetScreenDimensions();
+    st_widescreendelta = ST_WIDESCREENDELTA;
+
     // ready weapon ammo
     STlib_initNum(&w_ready,
 		  ST_AMMOX,
@@ -2369,21 +2410,21 @@ void ST_Init (void)
     }
 
     ST_loadData();
-    st_backing_screen = (pixel_t *) Z_Malloc((ST_WIDTH << 1) * (ST_HEIGHT << 1) * sizeof(*st_backing_screen), PU_STATIC, 0);
+    st_backing_screen = (pixel_t *) Z_Malloc(MAXWIDTH * (ST_HEIGHT << 1) * sizeof(*st_backing_screen), PU_STATIC, 0);
 }
 
 // [crispy] Demo Timer widget
 void ST_DrawDemoTimer (const int time)
 {
 	char buffer[16];
-	const int secs = time / TICRATE;
+	const int mins = time / (60 * TICRATE);
+	const float secs = (float)(time % (60 * TICRATE)) / TICRATE;
 	const int w = shortnum[0]->width;
 	int n, x;
 
-	n = M_snprintf(buffer, sizeof(buffer), "%02i %02i %02i",
-	               secs / 60, secs % 60, time % TICRATE);
+	n = M_snprintf(buffer, sizeof(buffer), "%02i %05.02f", mins, secs);
 
-	x = (viewwindowx >> crispy->hires) + (scaledviewwidth >> crispy->hires);
+	x = (viewwindowx >> crispy->hires) + (scaledviewwidth >> crispy->hires) - WIDESCREENDELTA;
 
 	// [crispy] draw the Demo Timer widget with gray numbers
 	dp_translation = cr[CR_GRAY];
