@@ -130,6 +130,27 @@ void DrawMessage(void)
     MN_DrTextA(player->message, 160 - MN_TextAWidth(player->message) / 2, 1);
 }
 
+//---------------------------------------------------------------------------
+//
+// PROC DrawCenterMessage
+//
+// [crispy]
+//
+//---------------------------------------------------------------------------
+
+void DrawCenterMessage(void)
+{
+    player_t* player;
+
+    player = &players[consoleplayer];
+    if (player->centerMessageTics <= 0 || !player->centerMessage)
+    {                           // No message
+        return;
+    }
+    // Place message above quit game message position so they don't overlap
+    MN_DrTextA(player->centerMessage, 160 - MN_TextAWidth(player->centerMessage) / 2, 70);
+}
+
 //---------------------------------------------------------------------------
 //
 // PROC D_Display
@@ -186,6 +207,27 @@ static void CrispyDrawStats (void)
     }
 }
 
+// [crispy] Draw the current FPS if show fps cheat is active
+static void CrispyDrawFps(void)
+{
+    short coord_x, height;
+    char str[32];
+    player_t* const player = &players[consoleplayer];
+
+    const int FontABaseLump = W_GetNumForName(DEH_String("FONTA_S")) + 1;
+    const patch_t* const p = W_CacheLumpNum(FontABaseLump + 'A' - 33, PU_CACHE);
+
+    height = SHORT(p->height) + 1;
+    coord_x = ORIGWIDTH - 6 * SHORT(p->width);
+
+    // [crispy] Only show FPS outside automap as it could obscure level coords
+    if (player->cheats & CF_SHOWFPS && !automapactive)
+    {
+        M_snprintf(str, sizeof(str), "%d F", crispy->fps);
+        MN_DrTextA(str, coord_x, height);
+    }
+}
+
 void R_ExecuteSetViewSize(void);
 
 extern boolean finalestage;
@@ -216,6 +258,7 @@ void D_Display(void)
             UpdateState |= I_FULLVIEW;
             SB_Drawer();
             CrispyDrawStats();
+            CrispyDrawFps();
             break;
         case GS_INTERMISSION:
             IN_Drawer();
@@ -248,6 +291,9 @@ void D_Display(void)
     // Handle player messages
     DrawMessage();
 
+    // [crispy] Handle centered player messages
+    DrawCenterMessage();
+
     // Menu drawing
     MN_Drawer();
 
@@ -308,6 +354,15 @@ void D_DoomLoop(void)
         // Move positional sounds
         S_UpdateSounds(players[consoleplayer].mo);
         D_Display();
+
+        // [crispy] post-rendering function pointer to apply config changes
+        // that affect rendering and that are better applied after the current
+        // frame has finished rendering
+        if (crispy->post_rendering_hook)
+        {
+            crispy->post_rendering_hook();
+            crispy->post_rendering_hook = NULL;
+        }
     }
 }
 
@@ -748,9 +803,14 @@ void D_BindVariables(void)
     }
 
     // [crispy] bind "crispness" config variables
+    M_BindIntVariable("crispy_hires",           &crispy->hires);
+    M_BindIntVariable("crispy_smoothscaling",   &crispy->smoothscaling);
     M_BindIntVariable("crispy_automapstats",    &crispy->automapstats);
     M_BindIntVariable("crispy_leveltime",       &crispy->leveltime);
     M_BindIntVariable("crispy_playercoords",    &crispy->playercoords);
+    M_BindIntVariable("crispy_secretmessage",   &crispy->secretmessage);
+    M_BindIntVariable("crispy_uncapped",        &crispy->uncapped);
+    M_BindIntVariable("crispy_vsync",           &crispy->vsync);
 }
 
 // 
