@@ -63,6 +63,7 @@ typedef enum
     MENU_FILES,
     MENU_LOAD,
     MENU_SAVE,
+    MENU_CRISPNESS,
     MENU_NONE
 } MenuType_t;
 
@@ -103,6 +104,14 @@ static boolean SCSaveGame(int option);
 static boolean SCMessages(int option);
 static boolean SCEndGame(int option);
 static boolean SCInfo(int option);
+static boolean CrispyHires(int option);
+static boolean CrispySmoothing(int option);
+static boolean CrispyAutomapStats(int option);
+static boolean CrispyLevelTime(int option);
+static boolean CrispyPlayerCoords(int option);
+static boolean CrispySecretMessage(int option);
+static boolean CrispyUncapped(int option);
+static boolean CrispyVsync(int option);
 static void DrawMainMenu(void);
 static void DrawEpisodeMenu(void);
 static void DrawSkillMenu(void);
@@ -114,12 +123,21 @@ static void MN_DrawInfo(void);
 static void DrawLoadMenu(void);
 static void DrawSaveMenu(void);
 static void DrawSlider(Menu_t * menu, int item, int width, int slot);
+static void DrawCrispnessMenu(void);
 void MN_LoadSlotText(void);
 
+// External Functions
+
+extern void I_ReInitGraphics(int reinit);
+extern void R_ExecuteSetViewSize(void);
+extern void AM_LevelInit(void);
+extern void AM_initVariables(void);
+
 // External Data
 
 extern int detailLevel;
 extern int screenblocks;
+extern boolean automapactive;
 
 // Public Data
 
@@ -251,13 +269,14 @@ static MenuItem_t OptionsItems[] = {
     {ITT_EFUNC, "MESSAGES : ", SCMessages, 0, MENU_NONE},
     {ITT_LRFUNC, "MOUSE SENSITIVITY", SCMouseSensi, 0, MENU_NONE},
     {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
-    {ITT_SETMENU, "MORE...", NULL, 0, MENU_OPTIONS2}
+    {ITT_SETMENU, "MORE...", NULL, 0, MENU_OPTIONS2},
+    {ITT_SETMENU, "CRISPNESS...", NULL, 0, MENU_CRISPNESS}
 };
 
 static Menu_t OptionsMenu = {
     88, 30,
     DrawOptionsMenu,
-    5, OptionsItems,
+    5+1, OptionsItems, // [JN] Extra item: Crispness menu
     0,
     MENU_MAIN
 };
@@ -279,6 +298,27 @@ static Menu_t Options2Menu = {
     MENU_OPTIONS
 };
 
+static MenuItem_t CrispnessItems[] = {
+    {ITT_LRFUNC, "HIGH RESOLUTION RENDERING:", CrispyHires, 0, MENU_NONE},
+    {ITT_LRFUNC, "SMOOTH PIXEL SCALING:", CrispySmoothing, 0, MENU_NONE},
+    {ITT_LRFUNC, "UNCAPPED FRAMERATE:", CrispyUncapped, 0, MENU_NONE},
+    {ITT_LRFUNC, "ENABLE VSYNC:", CrispyVsync, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_LRFUNC, "SHOW LEVEL STATS:", CrispyAutomapStats, 0, MENU_NONE},
+    {ITT_LRFUNC, "SHOW LEVEL TIME:", CrispyLevelTime, 0, MENU_NONE},
+    {ITT_LRFUNC, "SHOW PLAYER COORDS:", CrispyPlayerCoords, 0, MENU_NONE},
+    {ITT_LRFUNC, "REPORT REVEALED SECRETS:", CrispySecretMessage, 0, MENU_NONE},
+};
+
+static Menu_t CrispnessMenu = {
+    68, 40,
+    DrawCrispnessMenu,
+    10, CrispnessItems,
+    0,
+    MENU_OPTIONS
+};
+
 static Menu_t *Menus[] = {
     &MainMenu,
     &EpisodeMenu,
@@ -287,7 +327,8 @@ static Menu_t *Menus[] = {
     &Options2Menu,
     &FilesMenu,
     &LoadMenu,
-    &SaveMenu
+    &SaveMenu,
+    &CrispnessMenu
 };
 
 //---------------------------------------------------------------------------
@@ -523,15 +564,43 @@ void MN_Drawer(void)
         {
             if (item->type != ITT_EMPTY && item->text)
             {
+                if (CurrentMenu == &CrispnessMenu)
+                {
+                // [JN] Crispness menu: use small "A" font
+                MN_DrTextA(DEH_String(item->text), x, y);
+                }
+                else
+                {
                 MN_DrTextB(DEH_String(item->text), x, y);
+                }
             }
+            if (CurrentMenu == &CrispnessMenu)
+            {
+            // [JN] Crispness menu: use 10px vertical spacing for small font
+            y += ITEM_HEIGHT/2;
+            }
+            else
+            {
             y += ITEM_HEIGHT;
+            }
             item++;
         }
+        if (CurrentMenu == &CrispnessMenu)
+        {
+        // [JN] Crispness menu: use small blue gem instead of big red arrow.
+        // Blinks a bit faster and shifted right, closer to the text.
+        y = CurrentMenu->y + (CurrentItPos * (ITEM_HEIGHT/2)) + SELECTOR_YOFFSET;
+        selName = DEH_String(MenuTime & 8 ? "INVGEMR1" : "INVGEMR2");
+        V_DrawPatch(x + (SELECTOR_XOFFSET/2), y,
+                    W_CacheLumpName(selName, PU_CACHE));
+        }
+        else
+        {
         y = CurrentMenu->y + (CurrentItPos * ITEM_HEIGHT) + SELECTOR_YOFFSET;
         selName = DEH_String(MenuTime & 16 ? "M_SLCTR1" : "M_SLCTR2");
         V_DrawPatch(x + SELECTOR_XOFFSET, y,
                     W_CacheLumpName(selName, PU_CACHE));
+        }
     }
 }
 
@@ -932,7 +1001,8 @@ static boolean SCMouseSensi(int option)
 {
     if (option == RIGHT_DIR)
     {
-        if (mouseSensitivity < 9)
+        // [crispy] remove mouse sensitivity limit
+        if (mouseSensitivity < 255)
         {
             mouseSensitivity++;
         }
@@ -1031,6 +1101,86 @@ static boolean SCInfo(int option)
     return true;
 }
 
+//---------------------------------------------------------------------------
+//
+// Crispness menu: toggable features
+//
+//---------------------------------------------------------------------------
+
+static void CrispyHiresHook(void)
+{
+    crispy->hires = !crispy->hires;
+    // [crispy] re-initialize framebuffers, textures and renderer
+    I_ReInitGraphics(REINIT_FRAMEBUFFERS | REINIT_TEXTURES | REINIT_ASPECTRATIO);
+    // [crispy] re-calculate framebuffer coordinates
+    R_ExecuteSetViewSize();
+    // [crispy] scale the sky for new resolution
+    R_InitSkyMap();
+    // [crispy] re-calculate automap coordinates
+    AM_LevelInit();
+    if (automapactive) {
+        AM_initVariables();
+    }
+    // [crispy] refresh the status bar
+    SB_state = -1;
+}
+
+static boolean CrispyHires(int option)
+{
+    crispy->post_rendering_hook = CrispyHiresHook;
+
+    return true;
+}
+
+static boolean CrispySmoothing(int option)
+{
+    crispy->smoothscaling = !crispy->smoothscaling;
+    return true;
+}
+
+static boolean CrispyUncapped(int option)
+{
+    crispy->uncapped = !crispy->uncapped;
+    return true;
+}
+
+static void CrispyVsyncHook(void)
+{
+    crispy->vsync = !crispy->vsync;
+    I_ReInitGraphics(REINIT_RENDERER | REINIT_TEXTURES | REINIT_ASPECTRATIO);
+}
+
+static boolean CrispyVsync(int option)
+{
+    crispy->post_rendering_hook = CrispyVsyncHook;
+
+    return true;
+}
+
+static boolean CrispyAutomapStats(int option)
+{
+    crispy->automapstats = (crispy->automapstats + 1) % NUM_WIDGETS;
+    return true;
+}
+
+static boolean CrispyLevelTime(int option)
+{
+    crispy->leveltime = (crispy->leveltime + 1) % NUM_WIDGETS;
+    return true;
+}
+
+static boolean CrispyPlayerCoords(int option)
+{
+    crispy->playercoords = (crispy->playercoords + 1) % (NUM_WIDGETS - 1); // [crispy] disable "always" setting
+    return true;
+}
+
+static boolean CrispySecretMessage(int option)
+{
+    crispy->secretmessage = (crispy->secretmessage + 1) % NUM_SECRETMESSAGE; // [crispy] enable secret message
+    return true;
+}
+
 //---------------------------------------------------------------------------
 //
 // FUNC MN_Responder
@@ -1043,7 +1193,6 @@ boolean MN_Responder(event_t * event)
     int key;
     int i;
     MenuItem_t *item;
-    extern boolean automapactive;
     extern void D_StartTitle(void);
     extern void G_CheckDemoStatus(void);
     char *textBuffer;
@@ -1680,6 +1829,7 @@ static void DrawSlider(Menu_t * menu, int item, int width, int slot)
     int y;
     int x2;
     int count;
+    char	num[4];
 
     x = menu->x + 24;
     y = menu->y + 2 + (item * ITEM_HEIGHT);
@@ -1690,6 +1840,66 @@ static void DrawSlider(Menu_t * menu, int item, int width, int slot)
                                            : "M_SLDMD2"), PU_CACHE));
     }
     V_DrawPatch(x2, y, W_CacheLumpName(DEH_String("M_SLDRT"), PU_CACHE));
+
+    // [crispy] print the value
+    M_snprintf(num, 4, "%3d", slot);
+    MN_DrTextA(num, x2 + 32, y + 3);
+
+    // [crispy] do not crash anymore if the value is out of bounds
+    if (slot >= width)
+    {
+        slot = width - 1;
+    }
+
     V_DrawPatch(x + 4 + slot * 8, y + 7,
                 W_CacheLumpName(DEH_String("M_SLDKB"), PU_CACHE));
 }
+
+//---------------------------------------------------------------------------
+//
+// PROC DrawCrispnessMenu
+//
+//---------------------------------------------------------------------------
+
+static void DrawCrispnessMenu(void)
+{
+    static const char *title;
+
+    // Title
+    title = DEH_String("CRISPNESS");
+    MN_DrTextB(title, 160 - MN_TextBWidth(title) / 2, 6);
+
+    // Subheaders
+    MN_DrTextA("RENDERING", 63, 30);
+    MN_DrTextA("NAVIGATIONAL", 63, 90);
+
+    // Hires rendering
+    MN_DrTextA(crispy->hires ? "ON" : "OFF", 254, 40);
+
+    // Smooth pixel scaling
+    MN_DrTextA(crispy->smoothscaling ? "ON" : "OFF", 216, 50);
+
+    // Uncapped framerate
+    MN_DrTextA(crispy->uncapped ? "ON" : "OFF", 217, 60);
+
+    // Vsync
+    MN_DrTextA(crispy->vsync ? "ON" : "OFF", 167, 70);
+
+    // Show level stats
+    MN_DrTextA(crispy->automapstats == WIDGETS_OFF ? "NEVER" :
+               crispy->automapstats == WIDGETS_AUTOMAP ? "IN AUTOMAP" :
+                                                         "ALWAYS", 190, 100);
+
+    // Show level time
+    MN_DrTextA(crispy->leveltime == WIDGETS_OFF ? "NEVER" :
+               crispy->leveltime == WIDGETS_AUTOMAP ? "IN AUTOMAP" :
+                                                       "ALWAYS", 179, 110);
+
+    // Show player coords
+    MN_DrTextA(crispy->playercoords == WIDGETS_OFF ? "NEVER" : "IN AUTOMAP", 211, 120);
+
+    // Show secret message
+    MN_DrTextA(crispy->secretmessage == SECRETMESSAGE_OFF ? "OFF" :
+        crispy->secretmessage == SECRETMESSAGE_ON ? "ON" :
+        "COUNT", 250, 130);
+}
