@@ -743,6 +743,26 @@ void P_MobjThinker(mobj_t * mobj)
 {
     mobj_t *onmo;
 
+    // [crispy] suppress interpolation of player missiles for the first tic
+    if (mobj->interp == -1)
+    {
+        mobj->interp = false;
+    }
+    else
+    // [AM] Handle interpolation unless we're an active player.
+    if (!(mobj->player != NULL && mobj == mobj->player->mo))
+    {
+        // Assume we can interpolate at the beginning
+        // of the tic.
+        mobj->interp = true;
+
+        // Store starting position for mobj interpolation.
+        mobj->oldx = mobj->x;
+        mobj->oldy = mobj->y;
+        mobj->oldz = mobj->z;
+        mobj->oldangle = mobj->angle;
+    }
+
     // Handle X and Y momentums
     if (mobj->momx || mobj->momy || (mobj->flags & MF_SKULLFLY))
     {
@@ -926,6 +946,15 @@ mobj_t *P_SpawnMobj(fixed_t x, fixed_t y, fixed_t z, mobjtype_t type)
         mobj->flags2 &= ~MF2_FEETARECLIPPED;
     }
 
+    // [AM] Do not interpolate on spawn.
+    mobj->interp = false;
+
+    // [AM] Just in case interpolation is attempted...
+    mobj->oldx = mobj->x;
+    mobj->oldy = mobj->y;
+    mobj->oldz = mobj->z;
+    mobj->oldangle = mobj->angle;
+
     mobj->thinker.function = P_MobjThinker;
     P_AddThinker(&mobj->thinker);
     return (mobj);
@@ -993,6 +1022,9 @@ void P_SpawnPlayer(mapthing_t * mthing)
     p->playerstate = PST_LIVE;
     p->refire = 0;
     p->message = NULL;
+    // [JN] Reset ultimatemsg, so other messages may appear.
+    // See: https://github.com/chocolate-doom/chocolate-doom/issues/781
+    ultimatemsg = false;
     p->damagecount = 0;
     p->bonuscount = 0;
     p->chickenTics = 0;
@@ -1543,6 +1575,10 @@ mobj_t *P_SpawnPlayerMissile(mobj_t * source, mobjtype_t type)
         MissileMobj->y += (MissileMobj->momy >> 1);
         MissileMobj->z += (MissileMobj->momz >> 1);
     }
+
+    // [crispy] suppress interpolation of player missiles for the first tic
+    MissileMobj->interp = -1;
+
     if (!P_TryMove(MissileMobj, MissileMobj->x, MissileMobj->y))
     {                           // Exploded immediately
         P_ExplodeMissile(MissileMobj);
