@@ -20,6 +20,7 @@
 #include "deh_str.h"
 #include "i_system.h"
 #include "i_timer.h"
+#include "m_misc.h" // [crispy] So M_sprintf can be used
 #include "m_random.h"
 #include "p_local.h"
 #include "s_sound.h"
@@ -29,6 +30,8 @@
 
 #define MAX_AMBIENT_SFX 8       // Per level
 
+#define HUSTR_SECRETFOUND	"A SECRET IS REVEALED!" // [crispy] Secret message
+
 // Types
 
 typedef enum
@@ -193,7 +196,7 @@ anim_t *lastanim;
 int *TerrainTypes;
 struct
 {
-    char *name;
+    const char *name;
     int type;
 } TerrainTypeDefs[] =
 {
@@ -207,6 +210,10 @@ struct
 
 mobj_t LavaInflictor;
 
+// [AM] Fractional part of the current tic, in the half-open
+//      range of [0.0, 1.0).  Used for interpolation.
+extern fixed_t          fractionaltic;
+
 //----------------------------------------------------------------------------
 //
 // PROC P_InitLava
@@ -424,6 +431,13 @@ fixed_t P_FindNextHighestFloor(sector_t * sec, int currentheight)
         }
     }
 
+    // Don't return INT_MAX if no higher floor is found.
+
+    if (!h)
+    {
+        return height;
+    }
+
     // Compatibility note, in case of demo desyncs.
 
     if (h > 20)
@@ -835,6 +849,7 @@ void P_ShootSpecialLine(mobj_t * thing, line_t * line)
 
 void P_PlayerInSpecialSector(player_t * player)
 {
+    extern boolean messageson;
     sector_t *sector;
     static int pushTab[5] = {
         2048 * 5,
@@ -881,6 +896,18 @@ void P_PlayerInSpecialSector(player_t * player)
             break;
         case 9:                // SecretArea
             player->secretcount++;
+            // [crispy] Show centered "Secret Revealed!" message
+            if (messageson && crispy->secretmessage && player == &players[consoleplayer]) 
+            {
+                static char str_count[32];
+                
+                M_snprintf(str_count, sizeof(str_count), "SECRET %d OF %d REVEALED!", player->secretcount, totalsecret);
+
+                P_SetCenterMessage(&players[consoleplayer],
+                    (crispy->secretmessage == SECRETMESSAGE_COUNT) ? str_count : HUSTR_SECRETFOUND);
+                // Play an unused sound when secret found
+                S_StartSound(NULL, sfx_chicpk3);
+            }
             sector->special = 0;
             break;
         case 11:               // Exit_SuperDamage (DOOM E1M8 finale)
@@ -991,10 +1018,16 @@ void P_UpdateSpecials(void)
         switch (line->special)
         {
             case 48:           // Effect_Scroll_Left
-                sides[line->sidenum[0]].textureoffset += FRACUNIT;
+                // [crispy] smooth texture scrolling
+                sides[line->sidenum[0]].basetextureoffset += FRACUNIT;
+                sides[line->sidenum[0]].textureoffset =
+                    sides[line->sidenum[0]].basetextureoffset;
                 break;
             case 99:           // Effect_Scroll_Right
-                sides[line->sidenum[0]].textureoffset -= FRACUNIT;
+                // [crispy] smooth texture scrolling
+                sides[line->sidenum[0]].basetextureoffset -= FRACUNIT;
+                sides[line->sidenum[0]].textureoffset =
+                    sides[line->sidenum[0]].basetextureoffset;
                 break;
         }
     }
@@ -1028,6 +1061,31 @@ void P_UpdateSpecials(void)
     }
 }
 
+// [crispy] smooth texture scrolling
+void R_InterpolateTextureOffsets(void)
+{
+    if (crispy->uncapped && leveltime > oldleveltime)
+    {
+        int i;
+
+        for (i = 0; i < numlinespecials; i++)
+        {
+            const line_t* const line = linespeciallist[i];
+            side_t* const side = &sides[line->sidenum[0]];
+
+            if (line->special == 48)
+            {
+                side->textureoffset = side->basetextureoffset + fractionaltic;
+            }
+            else
+                if (line->special == 85)
+                {
+                    side->textureoffset = side->basetextureoffset - fractionaltic;
+                }
+        }
+    }
+}
+
 //============================================================
 //
 //      Special Stuff that can't be categorized
