@@ -114,14 +114,14 @@ void R_RenderMaskedSegRange(drawseg_t * ds, int x1, int x2)
 //
     if (curline->linedef->flags & ML_DONTPEGBOTTOM)
     {
-        dc_texturemid = frontsector->floorheight > backsector->floorheight
-            ? frontsector->floorheight : backsector->floorheight;
+        dc_texturemid = frontsector->interpfloorheight > backsector->interpfloorheight
+            ? frontsector->interpfloorheight : backsector->interpfloorheight;
         dc_texturemid = dc_texturemid + textureheight[texnum] - viewz;
     }
     else
     {
-        dc_texturemid = frontsector->ceilingheight < backsector->ceilingheight
-            ? frontsector->ceilingheight : backsector->ceilingheight;
+        dc_texturemid = frontsector->interpceilingheight < backsector->interpceilingheight
+            ? frontsector->interpceilingheight : backsector->interpceilingheight;
         dc_texturemid = dc_texturemid - viewz;
     }
     dc_texturemid += curline->sidedef->rowoffset;
@@ -424,8 +424,8 @@ void R_StoreWallRange(int start, int stop)
 // calculate texture boundaries and decide if floor / ceiling marks
 // are needed
 //
-    worldtop = frontsector->ceilingheight - viewz;
-    worldbottom = frontsector->floorheight - viewz;
+    worldtop = frontsector->interpceilingheight - viewz;
+    worldbottom = frontsector->interpfloorheight - viewz;
 
     midtexture = toptexture = bottomtexture = maskedtexture = 0;
     ds_p->maskedtexturecol = NULL;
@@ -440,7 +440,7 @@ void R_StoreWallRange(int start, int stop)
         markfloor = markceiling = true;
         if (linedef->flags & ML_DONTPEGBOTTOM)
         {
-            vtop = frontsector->floorheight +
+            vtop = frontsector->interpfloorheight +
                 textureheight[sidedef->midtexture];
             rw_midtexturemid = vtop - viewz;    // bottom of texture at bottom
         }
@@ -460,43 +460,43 @@ void R_StoreWallRange(int start, int stop)
 //
         ds_p->sprtopclip = ds_p->sprbottomclip = NULL;
         ds_p->silhouette = 0;
-        if (frontsector->floorheight > backsector->floorheight)
+        if (frontsector->interpfloorheight > backsector->interpfloorheight)
         {
             ds_p->silhouette = SIL_BOTTOM;
-            ds_p->bsilheight = frontsector->floorheight;
+            ds_p->bsilheight = frontsector->interpfloorheight;
         }
-        else if (backsector->floorheight > viewz)
+        else if (backsector->interpfloorheight > viewz)
         {
             ds_p->silhouette = SIL_BOTTOM;
             ds_p->bsilheight = INT_MAX;
 //                      ds_p->sprbottomclip = negonearray;
         }
-        if (frontsector->ceilingheight < backsector->ceilingheight)
+        if (frontsector->interpceilingheight < backsector->interpceilingheight)
         {
             ds_p->silhouette |= SIL_TOP;
-            ds_p->tsilheight = frontsector->ceilingheight;
+            ds_p->tsilheight = frontsector->interpceilingheight;
         }
-        else if (backsector->ceilingheight < viewz)
+        else if (backsector->interpceilingheight < viewz)
         {
             ds_p->silhouette |= SIL_TOP;
             ds_p->tsilheight = INT_MIN;
 //                      ds_p->sprtopclip = screenheightarray;
         }
 
-        if (backsector->ceilingheight <= frontsector->floorheight)
+        if (backsector->interpceilingheight <= frontsector->interpfloorheight)
         {
             ds_p->sprbottomclip = negonearray;
             ds_p->bsilheight = INT_MAX;
             ds_p->silhouette |= SIL_BOTTOM;
         }
-        if (backsector->floorheight >= frontsector->ceilingheight)
+        if (backsector->interpfloorheight >= frontsector->interpceilingheight)
         {
             ds_p->sprtopclip = screenheightarray;
             ds_p->tsilheight = INT_MIN;
             ds_p->silhouette |= SIL_TOP;
         }
-        worldhigh = backsector->ceilingheight - viewz;
-        worldlow = backsector->floorheight - viewz;
+        worldhigh = backsector->interpceilingheight - viewz;
+        worldlow = backsector->interpfloorheight - viewz;
 
         // hack to allow height changes in outdoor areas
         if (frontsector->ceilingpic == skyflatnum
@@ -517,8 +517,8 @@ void R_StoreWallRange(int start, int stop)
         else
             markceiling = false;        // same plane on both sides
 
-        if (backsector->ceilingheight <= frontsector->floorheight
-            || backsector->floorheight >= frontsector->ceilingheight)
+        if (backsector->interpceilingheight <= frontsector->interpfloorheight
+            || backsector->interpfloorheight >= frontsector->interpceilingheight)
             markceiling = markfloor = true;     // closed door
 
         if (worldhigh < worldtop)
@@ -528,7 +528,7 @@ void R_StoreWallRange(int start, int stop)
                 rw_toptexturemid = worldtop;    // top of texture at top
             else
             {
-                vtop = backsector->ceilingheight +
+                vtop = backsector->interpceilingheight +
                     textureheight[sidedef->toptexture];
                 rw_toptexturemid = vtop - viewz;        // bottom of texture
             }
@@ -602,9 +602,9 @@ void R_StoreWallRange(int start, int stop)
 // if a floor / ceiling plane is on the wrong side of the view plane
 // it is definately invisible and doesn't need to be marked
 //
-    if (frontsector->floorheight >= viewz)
+    if (frontsector->interpfloorheight >= viewz)
         markfloor = false;      // above view plane
-    if (frontsector->ceilingheight <= viewz
+    if (frontsector->interpceilingheight <= viewz
         && frontsector->ceilingpic != skyflatnum)
         markceiling = false;    // below view plane
 
