@@ -1123,6 +1123,22 @@ static default_t extra_defaults_list[] =
     //
 
     CONFIG_VARIABLE_INT(mouseb_nextweapon),
+    
+    //!
+    // @game heretic
+    //
+    // Mouse button to move to the left in the inventory.
+    //
+
+    CONFIG_VARIABLE_INT(mouseb_invleft),
+
+    //!
+    // @game heretic
+    //
+    // Mouse button to move to the right in the inventory.
+    //
+
+    CONFIG_VARIABLE_INT(mouseb_invright),
 
     //!
     // If non-zero, double-clicking a mouse button acts like pressing
@@ -1627,6 +1643,78 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_KEY(key_nextweapon),
 
+    //!
+    // @game heretic
+    //
+    // Key to use "quartz flask" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_quartz),
+
+    //!
+    // @game heretic
+    //
+    // Key to use "mystic urn" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_urn),
+
+    //!
+    // @game heretic
+    //
+    // Key to use "timebomb of the ancients" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_bomb),
+
+    //!
+    // @game heretic
+    //
+    // Key to use "tome of power" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_tome),
+
+    //!
+    // @game heretic
+    //
+    // Key to use "ring of invincibility" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_ring),
+
+    //!
+    // @game heretic
+    //
+    // Key to use "chaos device" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_chaosdevice),
+
+    //!
+    // @game heretic
+    //
+    // Key to use "shadowsphere" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_shadowsphere),
+
+    //!
+    // @game heretic
+    //
+    // Key to use "wings of wrath" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_wings),
+
+    //!
+    // @game heretic
+    //
+    // Key to use "torch" artifact.
+    //
+
+    CONFIG_VARIABLE_KEY(key_arti_torch),
+
     //!
     // @game hexen
     //
@@ -1780,7 +1868,7 @@ static default_t extra_defaults_list[] =
     CONFIG_VARIABLE_KEY(key_toggleautorun),
 
     //!
-    // @game doom
+    // @game doom heretic
     // Toggle vertical mouse movement.
     //
 
@@ -2114,6 +2202,14 @@ static default_t extra_defaults_list[] =
     //
 
     CONFIG_VARIABLE_INT(crispy_weaponsquat),
+
+    //!
+    // @game doom
+    //
+    // Widescreen rendering.
+    //
+
+    CONFIG_VARIABLE_INT(crispy_widescreen),
 };
 
 static default_collection_t extra_defaults =
