@@ -36,6 +36,7 @@ extern int key_speed;
 
 extern int key_jump;
 extern int key_toggleautorun;
+extern int key_togglenovert;
  
 extern int key_flyup;
 extern int key_flydown;
@@ -73,6 +74,16 @@ extern int key_weapon6;
 extern int key_weapon7;
 extern int key_weapon8;
 
+extern int key_arti_quartz;
+extern int key_arti_urn;
+extern int key_arti_bomb;
+extern int key_arti_tome;
+extern int key_arti_ring;
+extern int key_arti_chaosdevice;
+extern int key_arti_shadowsphere;
+extern int key_arti_wings;
+extern int key_arti_torch;
+
 extern int key_arti_all;
 extern int key_arti_health;
 extern int key_arti_poisonbag;
@@ -149,6 +160,8 @@ extern int mousebreverse;
 
 extern int mousebprevweapon;
 extern int mousebnextweapon;
+extern int mousebinvleft;
+extern int mousebinvright;
 
 extern int joybfire;
 extern int joybstrafe;
