@@ -48,6 +48,9 @@ static int *controls[] = { &key_left, &key_right, &key_up, &key_down,
                            &key_weapon1, &key_weapon2, &key_weapon3,
                            &key_weapon4, &key_weapon5, &key_weapon6,
                            &key_weapon7, &key_weapon8,
+                           &key_arti_quartz, &key_arti_urn, &key_arti_bomb,
+                           &key_arti_tome, &key_arti_ring, &key_arti_chaosdevice,
+                           &key_arti_shadowsphere, &key_arti_wings, &key_arti_torch,
                            &key_arti_all, &key_arti_health, &key_arti_poisonbag,
                            &key_arti_blastradius, &key_arti_teleport,
                            &key_arti_teleportother, &key_arti_egg,
@@ -226,6 +229,18 @@ static void ConfigExtraKeys(TXT_UNCAST_ARG(widget), TXT_UNCAST_ARG(unused))
         AddKeyControl(table, "Toggle vert. mouse", &key_togglenovert);
         AddKeyControl(table, "Quick Reverse", &key_reverse);
         }
+        else if (gamemission == heretic)
+        {
+        AddSectionLabel(table, "View", false);
+
+        AddKeyControl(table, "Look up", &key_lookup);
+        AddKeyControl(table, "Look down", &key_lookdown);
+        AddKeyControl(table, "Center view", &key_lookcenter);
+
+        AddSectionLabel(table, "Movement", true);
+        AddKeyControl(table, "Toggle always run", &key_toggleautorun);
+        AddKeyControl(table, "Toggle vert. mouse", &key_togglenovert);
+        }
         else
         {
         AddSectionLabel(table, "View", false);
@@ -270,6 +285,21 @@ static void ConfigExtraKeys(TXT_UNCAST_ARG(widget), TXT_UNCAST_ARG(unused))
             AddKeyControl(table, "Use artifact", &key_useartifact);
         }
 
+        if (gamemission == heretic)
+        {
+            AddSectionLabel(table, "Artifacts", true);
+
+            AddKeyControl(table, "Quartz Flask", &key_arti_quartz);
+            AddKeyControl(table, "Mystic Urn", &key_arti_urn);
+            AddKeyControl(table, "Timebomb", &key_arti_bomb);
+            AddKeyControl(table, "Tome of Power", &key_arti_tome);
+            AddKeyControl(table, "Ring of Invincibility ", &key_arti_ring);
+            AddKeyControl(table, "Chaos Device", &key_arti_chaosdevice);
+            AddKeyControl(table, "Shadowsphere", &key_arti_shadowsphere);
+            AddKeyControl(table, "Wings of Wrath", &key_arti_wings);
+            AddKeyControl(table, "Torch", &key_arti_torch);
+        }
+
         if (gamemission == hexen)
         {
             AddSectionLabel(table, "Artifacts", true);
